@@ -12,7 +12,6 @@ def main ():
     start_screen.background_color = "white"
     with resources.path("pygameplus.demos.img", "mole.png") as image_path:
         mole_image = image_path
-    print(mole_image)
     start_screen.background_image = mole_image
     start_screen.open()
     
@@ -25,6 +24,7 @@ def main ():
     
     def open_main_screen ():
         screen.open()
+        music_stream.play(loops=-1)
     
     start_screen.on_key_press(open_main_screen)
     
@@ -34,6 +34,10 @@ def main ():
     # Creating a screen
     screen = Screen(640, 360, "Whack-A-Mole")
     screen.background_color = "lightgreen"
+
+    # Load the background music
+    with resources.path("pygameplus.demos.audio", "hampster-march.mp3") as audio_path:
+        music_stream.load(audio_path)
     
     # Create a POW sprite
     with resources.path("pygameplus.demos.img", "pow.png") as image_path:
@@ -72,10 +76,17 @@ def main ():
     
     # Bind the function to mouse movement on the screen.
     screen.on_mouse_move(move_mallet)
+
+    # Load the sound effects
+    with resources.path("pygameplus.demos.audio", "whack-mole.mp3") as audio_path:
+        hit_sound = Sound(audio_path)
+    with resources.path("pygameplus.demos.audio", "whack-wood.mp3") as audio_path:
+        miss_sound = Sound(audio_path)
     
     # Function that whacks the mallet when the mouse is
     # clicked
-    def whack_mallet ():
+    def whack_mallet (pos):
+        miss_sound.play()
         mallet.turn_left(60)
     
     # Bind the function to mouse clicks
@@ -92,6 +103,7 @@ def main ():
     # Function that pops up the POW when the mole
     # is hit
     def mole_hit (pos):
+        hit_sound.play()
         pow_flash.position = pos
         screen.add(pow_flash)
     
@@ -100,6 +112,7 @@ def main ():
 
     def pause_game ():
         pause_screen.open()
+        music_stream.pause()
 
     screen.on_key_press(pause_game, "space")
     
@@ -119,6 +132,7 @@ def main ():
 
     def resume_game ():
         screen.open()
+        music_stream.unpause()
         move_mole()
         screen.on_timer(move_mole, 2000, repeat=True)
     
