@@ -175,6 +175,9 @@ class Screen (pygame.sprite.LayeredUpdates):
     @size.setter
     def size (self, new_dimensions):
 
+        old_width = self._width
+        old_height = self._height
+
         try:
             self._width, self._height = [int(d) for d in new_dimensions]
         except:
@@ -189,7 +192,9 @@ class Screen (pygame.sprite.LayeredUpdates):
         # Create a new canvas with the new size
         old_canvas = self._canvas
         self._canvas = pygame.Surface((self._width, self._height), pygame.SRCALPHA)
-        # TODO: blit the old canvas onto the new canvas
+        x = (self._width - old_width) // 2
+        y = (self._height - old_height) // 2
+        self._canvas.blit(old_canvas, (x, y))
 
         # Change the rect for the background image to keep it centered.
         if self._image_rect is not None:
@@ -461,13 +466,23 @@ class Screen (pygame.sprite.LayeredUpdates):
         if self._image is not None:
             surface.blit(self._image, self._image_rect)
 
-        # Draw any drawings
-        surface.blit(self._canvas, (0, 0))
-        surface.blit(self._update_drawings, (0, 0))
+        # Create a sprite to hold the drawings
+        canvas_sprite = pygame.sprite.Sprite()
+        canvas_sprite.image = pygame.Surface((self._width, self._height), 
+                                             pygame.SRCALPHA)
+        canvas_sprite.image.blit(self._canvas, (0, 0))
+        canvas_sprite.image.blit(self._update_drawings, (0, 0))
+        canvas_sprite.rect = pygame.Rect(0, 0, self._width, self._height)
+        self.add(canvas_sprite, layer=-1)
 
         # Draw the sprites
-        return pygame.sprite.LayeredUpdates.draw(self, surface)
+        ret = pygame.sprite.LayeredUpdates.draw(self, surface)
 
+        # Remove the drawings sprite
+        self.remove(canvas_sprite)
+
+        return ret
+    
     
     def redraw (self):
         '''
