@@ -874,6 +874,7 @@ class Sprite (pygame.sprite.Sprite):
 
         # Flag that the image may have flipped and needs to be transformed
         self._dirty_flip = True
+        self._dirty_mask = True
 
 
     @property
@@ -891,6 +892,7 @@ class Sprite (pygame.sprite.Sprite):
 
         # Flag that the image may have flipped and needs to be transformed
         self._dirty_flip = True
+        self._dirty_mask = True
 
 
     @property
@@ -1198,7 +1200,7 @@ class Sprite (pygame.sprite.Sprite):
                 other_sprite._clean_image()
                 if method == pygame.sprite.collide_mask:
                     other_sprite._clean_mask()
-                if other in active_screen and bool(method(self, other_sprite)):
+                if other_sprite in active_screen and bool(method(self, other_sprite)):
                     hit_list.append(other)
             return hit_list
 
@@ -1263,7 +1265,7 @@ class Sprite (pygame.sprite.Sprite):
                 other_sprite._clean_image()
                 if method == pygame.sprite.collide_mask:
                     other_sprite._clean_mask()
-                if other in active_screen and bool(method(self, other_sprite)):
+                if other_sprite in active_screen and bool(method(self, other_sprite)):
                     return True
             return False
 
@@ -1276,7 +1278,7 @@ class Sprite (pygame.sprite.Sprite):
 
         # If given an invalid argument, just return False
         else:
-            return ValueError("Invalid argument!")
+            raise ValueError("Invalid argument!")
 
 
     ### Add Custom Update Function
